@@ -209,7 +209,7 @@ def add_remote_key(fingerprint, path=None):
         subprocess.run(["rm", "-f", keyring, tmp_keyring])
         # Move the key to proper place
         # path if given (for PPAs) or globally trusted in APT dir otherwise
-        if path == None:
+        if path is None:
             subprocess.run(["mv", key, trusted_key])
         else:
             subprocess.run(["mv", key, path])
@@ -295,7 +295,7 @@ def expand_ppa_line(abrev, distro_codename):
     ppa_id = "%s-%s-%s" % (encode(ppa_owner), encode(ppa_name), distro_codename)
     source_path = f"/etc/apt/sources.list.d/{ppa_id}.list"
     key_path = f"/etc/apt/keyrings/{ppa_id}.gpg"
-    line = f"deb [arch=amd64 signed-by={key_path}] https://ppa.launchpadcontent.net/{ppa_owner}/{ppa_name}/ubuntu {distro_codename} main"
+    line = f"deb [signed-by={key_path}] https://ppa.launchpadcontent.net/{ppa_owner}/{ppa_name}/ubuntu {distro_codename} main"
     return (line, source_path, key_path)
 
 def expand_http_line(line, distro_codename):
@@ -1420,7 +1420,7 @@ class Application(object):
             info_text = "%s\n\n%s\n\n%s\n\n%s" % (line,
                 self.format_string(ppa_info["displayname"]),
                 self.format_string(ppa_info["description"]), str(ppa_info["web_link"]))
-            if self.show_confirm_ppa_dialog(info_text):
+            if self.show_confirm_ppa_dialog(ppa_info["displayname"], info_text):
                 (deb_line, file, key_path) = expand_ppa_line(line.strip(), self.config["general"]["base_codename"])
                 deb_line = expand_http_line(deb_line, self.config["general"]["base_codename"])
                 debsrc_line = 'deb-src' + deb_line[3:]
@@ -1550,7 +1550,7 @@ class Application(object):
         start_line = ""
         default_line = "deb http://packages.domain.com/ %s main" % self.config["general"]["base_codename"]
         clipboard_text = self.get_clipboard_text("deb")
-        if clipboard_text != None:
+        if clipboard_text is not None:
             start_line = clipboard_text
         else:
             start_line = default_line
@@ -1627,7 +1627,7 @@ class Application(object):
         else:
             return False
 
-    def show_confirm_ppa_dialog(self, message):
+    def show_confirm_ppa_dialog(self, title, message):
         b = Gtk.TextBuffer()
         b.set_text(message)
         t =  Gtk.TextView()
@@ -1638,13 +1638,12 @@ class Application(object):
         s.set_shadow_type(Gtk.ShadowType.OUT)
         default_button = Gtk.ResponseType.ACCEPT
         confirmation_button = Gtk.ResponseType.ACCEPT
-        d = Gtk.Dialog(None, self._main_window,
-                       Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                       (_("Cancel"), Gtk.ResponseType.REJECT,
-                       _("OK"), Gtk.ResponseType.ACCEPT))
+        d = Gtk.Dialog(transient_for=self._main_window, modal=True, destroy_with_parent=True)
+        d.add_buttons(Gtk.STOCK_CANCEL, Gtk.ResponseType.REJECT, Gtk.STOCK_OK, Gtk.ResponseType.ACCEPT)
         d.set_size_request(550, 400)
-        d.get_content_area().pack_start(s, True, True, 0)
-        d.set_title("")
+        d.get_content_area().pack_start(s, True, True, 12)
+        d.set_border_width(12)
+        d.set_title(title)
         s.show()
         s.add(t)
         t.show()
@@ -1702,14 +1701,14 @@ class Application(object):
 
     def ppa_toggled(self, renderer, path):
         iter = self._ppa_model.get_iter(path)
-        if (iter != None):
+        if iter is not None:
             repository = self._ppa_model.get_value(iter, 0)
             repository.switch()
             self.builder.get_object("button_ppa_examine").set_sensitive(repository.selected)
 
     def repository_toggled(self, renderer, path):
         iter = self._repository_model.get_iter(path)
-        if (iter != None):
+        if iter is not None:
             repository = self._repository_model.get_value(iter, 0)
             repository.switch()
 
